@@ -28,6 +28,7 @@ def lineplot(
     limits: Optional[List[float]] = None,
     independent_x: bool = True,
     independent_y: bool = False,
+    log_y: bool = False,
     y_axis: Optional[alt.Axis] = None,
     spacing: int = 5,
     color: Optional[Union[str, alt.Color]] = None,
@@ -60,6 +61,7 @@ def lineplot(
         limits: Limits for y-axis
         independent_x: Whether x-axes are independent
         independent_y: Whether y-axes are independent
+        log_y: Whether y-axes should be log-scale
         y_axis: Axis for y
         spacing: Spacing between facets
         color: Colorscale
@@ -88,6 +90,9 @@ def lineplot(
 
     y_kwarg = {}
 
+    if log_y:
+        y_kwarg["base"] = 10
+
     if limits is not None:
         y_kwarg["scale"] = alt.Scale(zero=False, domain=limits)
     else:
